==> imuikit-1.0.1.20170902-sources.jar: com/xdja/im/uikit/IntentParam.java <==
package com.xdja.im.uikit;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.IntDef;

import com.xdja.im.common.utils.CommonTool;
import com.xdja.im.uikit.constans.Constant;

import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

/**
 * @Package: com.xdja.im.uikit
 * @Author: xdjaxa
 * @Creation: 2017-05-23 10:04
 * @Version V1.0
 * @Description:
 */
public class IntentParam {

    /**
     * 启动聊天界面action
     */
    public static final String ACTION_CHAT = "action.xjda.im.uikit.chatlist";

    /**
     * UiKit 默认的聊天界面
     */
    public static final String ACTION_CHAT_DEF = "action.xjda.im.uikit.chatlist.def";
    /**
     * 用户设置界面action
     */
    public static final String ACTION_USER_DETAIL = "action.xdja.im.uikit.user.detail";
    /**
     * 进入聊天相关参数
     */
    public static final String PARAM_CHAT = "Param_chatList";
    /**
     * 进入设置相关参数
     */
    public static final String PARAM_SETTING = "Param_setting";
    /**
     * 会话ID，在同一账号中唯一
     */
    public static final String PARAM_SESSION_ID = "talkerId";
    /**
     * 会话类型，值为单聊或者群聊
     * 值见{@link Session}
     */
    public static final String PARAM_SESSION_TYPE = "talkType";
    /**
     * 账号信息
     */
    public static final String PARAM_ACCOUNT = "account";

    @Retention(RetentionPolicy.SOURCE)
    @IntDef(value = {SESSION_TYPE_P2P, SESSION_TYPE_P2G})
    public @interface Session {
    }

    /**
     * 单人聊天
     */
    public static final int SESSION_TYPE_P2P = 1;
    /**
     * 群组聊天
     */
    public static final int SESSION_TYPE_P2G = 2;

    /**
     * 启动聊天界面
     *
     * @param context     上下文
     * @param sessionId   会话ID
     * @param sessionType 会话类型
     */
    public static void startChatActivity(Context context, String sessionId, int sessionType) {
        Intent intent = new Intent();
        if (CommonTool.getPlatformType() == Constant.PLATFORM_OA) {
            intent.setAction(ACTION_CHAT);
        } else {
            intent.setAction(ACTION_CHAT_DEF);
        }
        Bundle arguments = new Bundle();
        arguments.putString(IntentParam.PARAM_SESSION_ID, sessionId);
        arguments.putInt(IntentParam.PARAM_SESSION_TYPE, sessionType);
        intent.putExtras(arguments);
        intent.setPackage(context.getPackageName());
        context.startActivity(intent);
    }

    /**
     * 启动聊天界面
     *
     * @param context 上下文
     */
    public static void startChatActivity(Context context, Bundle arguments) {
        Intent intent = new Intent();
        intent.setAction(ACTION_CHAT);
        intent.putExtra(PARAM_CHAT, arguments);
        intent.setPackage(context.getPackageName());
        context.startActivity(intent);
    }

    /**
     * 启动设置界面
     *
     * @param context
     * @param account
     */
    public static void startSettingActivity(Context context, String account) {
        Intent intent = new Intent();
        intent.setAction(ACTION_USER_DETAIL);
        Bundle arguments = new Bundle();
        arguments.putString(IntentParam.PARAM_ACCOUNT, account);
        intent.putExtra(PARAM_SETTING, arguments);
        intent.setPackage(context.getPackageName());
        context.startActivity(intent);
    }
}

==> imuikit-1.0.4.20171106_2-sources.jar: com/xdja/im/uikit/IntentParam.java <==
package com.xdja.im.uikit;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.IntDef;

import com.xdja.im.common.utils.CommonTool;
import com.xdja.im.core.config.ConstDef;
import com.xdja.im.uikit.constans.Constant;

import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

/**
 * @Package: com.xdja.im.uikit
 * @Author: xdjaxa
 * @Creation: 2017-05-23 10:04
 * @Version V1.0
 * @Description:
 */
public class IntentParam {

    /**
     * 启动聊天界面action
     */
    public static final String ACTION_CHAT = "action.xjda.im.uikit.chatlist";

    /**
     * UiKit 默认的聊天界面
     */
    public static final String ACTION_CHAT_DEF = "action.xjda.im.uikit.chatlist.def";
    /**
     * 用户设置界面action
     */
    public static final String ACTION_USER_DETAIL = "action.xdja.im.uikit.user.detail";
    public static final String ACTION_GROUP_DETAIL = "action.xdja.im.uikit.group.detail";
    /**
     * 进入聊天相关参数
     */
    public static final String PARAM_CHAT = "Param_chatList";
    /**
     * 进入设置相关参数
     */
    public static final String PARAM_SETTING = "Param_setting";
    /**
     * 会话ID，在同一账号中唯一
     */
    public static final String PARAM_SESSION_ID = "talkerId";
    /**
     * 会话类型，值为单聊或者群聊
     * 值见{@link Session}
     */
    public static final String PARAM_SESSION_TYPE = "talkType";
    /**
     * 账号信息
     */
    public static final String PARAM_ACCOUNT = "account";

    @Retention(RetentionPolicy.SOURCE)
    @IntDef(value = {SESSION_TYPE_P2P, SESSION_TYPE_P2G})
    public @interface Session {
    }

    /**
     * 单人聊天
     */
    public static final int SESSION_TYPE_P2P = 1;
    /**
     * 群组聊天
     */
    public static final int SESSION_TYPE_P2G = 2;

    /**
     * 启动聊天界面
     *
     * @param context     上下文
     * @param sessionId   会话ID
     * @param sessionType 会话类型
     */
    public static void startChatActivity(Context context, String sessionId, int sessionType) {
        Intent intent = new Intent();
        if (CommonTool.getPlatformType() == Constant.PLATFORM_OA) {
            intent.setAction(ACTION_CHAT);
        } else {
            intent.setAction(context.getPackageName() + "." + ACTION_CHAT_DEF);
        }
        Bundle arguments = new Bundle();
        arguments.putString(IntentParam.PARAM_SESSION_ID, sessionId);
        arguments.putInt(IntentParam.PARAM_SESSION_TYPE, sessionType);
        intent.putExtras(arguments);
        intent.setPackage(context.getPackageName());
        context.startActivity(intent);
    }

    /**
     * 启动聊天界面
     *
     * @param context 上下文
     */
    public static void startChatActivity(Context context, Bundle arguments) {
        Intent intent = new Intent();
        intent.setAction(ACTION_CHAT);
        intent.putExtra(PARAM_CHAT, arguments);
        intent.setPackage(context.getPackageName());
        context.startActivity(intent);
    }

    /**
     * 启动设置界面
     *
     * @param context
     * @param sessionId
     * @param sessionType
     */
    public static void startSettingActivity(Context context, String sessionId, int sessionType) {
        Intent intent = new Intent();
        if (sessionType == ConstDef.CHAT_TYPE_P2P) {
            intent.setAction(ACTION_USER_DETAIL);
        } else {
            intent.setAction(ACTION_GROUP_DETAIL);
        }
        Bundle arguments = new Bundle();
        arguments.putString(IntentParam.PARAM_SESSION_ID, sessionId);
        arguments.putInt(IntentParam.PARAM_SESSION_TYPE, sessionType);
        intent.putExtra(PARAM_SETTING, arguments);
        intent.setPackage(context.getPackageName());
        context.startActivity(intent);
    }
}
